Module codegen

Module codegen 

Codegen for view! macro.

Implementation note: We are not using the quote::ToTokens trait because we need to pass additional information to the codegen such as which mode (Client, Hydrate, SSR), etc…

Structs

Codegen