Codegen for view! macro.
view!
Implementation note: We are not using the quote::ToTokens trait because we need to pass additional information to the codegen such as which mode (Client, Hydrate, SSR), etc…
quote::ToTokens